( cd usr/bin ; rm -rf hattrib )
( cd usr/bin ; ln -sf hmount hattrib )
( cd usr/bin ; rm -rf hcd )
( cd usr/bin ; ln -sf hmount hcd )
( cd usr/bin ; rm -rf hcopy )
( cd usr/bin ; ln -sf hmount hcopy )
( cd usr/bin ; rm -rf hdel )
( cd usr/bin ; ln -sf hmount hdel )
( cd usr/bin ; rm -rf hdir )
( cd usr/bin ; ln -sf hmount hdir )
( cd usr/bin ; rm -rf hformat )
( cd usr/bin ; ln -sf hmount hformat )
( cd usr/bin ; rm -rf hls )
( cd usr/bin ; ln -sf hmount hls )
( cd usr/bin ; rm -rf hmkdir )
( cd usr/bin ; ln -sf hmount hmkdir )
( cd usr/bin ; rm -rf hpwd )
( cd usr/bin ; ln -sf hmount hpwd )
( cd usr/bin ; rm -rf hrename )
( cd usr/bin ; ln -sf hmount hrename )
( cd usr/bin ; rm -rf hrmdir )
( cd usr/bin ; ln -sf hmount hrmdir )
( cd usr/bin ; rm -rf humount )
( cd usr/bin ; ln -sf hmount humount )
( cd usr/bin ; rm -rf hvol )
( cd usr/bin ; ln -sf hmount hvol )
